from ._get_uniprot_id_by_protein_symbol import get_uniprot_id_by_protein_symbol
from ._get_uniprot_protein_info import get_uniprot_protein_info

__all__ = [
    "get_uniprot_id_by_protein_symbol",
    "get_uniprot_protein_info",
]
