from ._get_alphafold_info_by_protein_symbol import get_alphafold_info_by_protein_symbol
from ._get_alphafold_info_by_uniprot_id import get_alphafold_info_by_uniprot_id

__all__ = [
    "get_alphafold_info_by_protein_symbol",
    "get_alphafold_info_by_uniprot_id",
]
